@@ -279,7 +279,7 @@ class PODReader(Reader):
         # choose the right header depending on the date
         with file_opener(fileobj or filename) as fd_:
             self.tbm_head, self.head = self.read_header(
-                filename, fileobj=fd_)
+                filename, fileobj=fd_, header_date=self.header_date)
             if self.tbm_head:
                 tbm_offset = tbm_header.itemsize
             else:
@@ -302,12 +302,14 @@ class PODReader(Reader):
         return self.head, self.scans
 
     @classmethod
-    def read_header(cls, filename, fileobj=None):
+    def read_header(cls, filename, fileobj=None, header_date="auto"):
         """Read the file header.
 
         Args:
             filename (str): Path to GAC/LAC file
             fileobj: An open file object to read from. (optional)
+            header_date: date to use to choose the header.
+                Defaults to "auto" to use the data to pick the header corresponding to the date of the file.
 
         Returns:
             archive_header (struct): archive header
@@ -332,19 +334,7 @@ class PODReader(Reader):
                 fd_.seek(0)
                 tbm_head = None
                 tbm_offset = 0
-            # read header
-            head0, = np.frombuffer(
-                fd_.read(header0.itemsize),
-                dtype=header0, count=1)
-            year, jday, _ = cls.decode_timestamps(head0["start_time"])
-            start_date = (datetime.date(year, 1, 1) +
-                          datetime.timedelta(days=int(jday) - 1))
-            if start_date < datetime.date(1992, 9, 8):
-                header = header1
-            elif start_date <= datetime.date(1994, 11, 15):
-                header = header2
-            else:
-                header = header3
+            header = cls.choose_header_based_on_timestamp(header_date, fd_)
             fd_.seek(tbm_offset, 0)
             # need to copy frombuffer to have write access on head
             head, = np.frombuffer(
@@ -354,6 +344,31 @@ class PODReader(Reader):
         cls._validate_header(head)
         return tbm_head, head
 
+    @classmethod
+    def choose_header_based_on_timestamp(cls, header_date, fd_):
+        """Choose the header dtype based on the timestamp."""
+        if header_date == "auto":
+            header_date = cls.get_start_date(fd_)
+        if header_date < datetime.date(1992, 9, 8):
+            header = header1
+        elif header_date <= datetime.date(1994, 11, 15):
+            header = header2
+        else:
+            header = header3
+        return header
+
+    @classmethod
+    def get_start_date(cls, fd_):
+        """Get the start time from the filestream."""
+        head0, = np.frombuffer(
+                    fd_.read(header0.itemsize),
+                    dtype=header0, count=1)
+        year, jday, _ = cls.decode_timestamps(head0["start_time"])
+        header_date = (datetime.date(year, 1, 1) +
+                       datetime.timedelta(days=int(jday) - 1))
+
+        return header_date
+
     @classmethod
     def _validate_header(cls, header):
         """Check if the header belongs to this reader."""
